/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import java.util.Collections;
import java.util.List;

import org.conqat.ide.commons.ui.jface.TreeContentProviderBase;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;

/**
 * {@link ITreeContentProvider} based on {@link IModelElementHandler}. A
 * subclass can override the {@link #getChildren(EObject)} method to provide its
 * own content.
 * 
 * @author mou
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 21565202D54B03924D0B32263189AEF1
 */
public class ModelElementTreeContentProvider extends TreeContentProviderBase {

	/** the root elements */
	private final List<? extends EObject> roots;

	/** Constructor */
	public ModelElementTreeContentProvider(List<? extends EObject> input) {
		this.roots = input;
	}

	/** {@inheritDoc} */
	@Override
	public Object getParent(Object element) {
		if(element instanceof EObject) {
			if(roots.contains(element))
				return null;
			return ((EObject)element).eContainer();
		}

		return new Object[0];
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getChildren(Object parentElement) {
		if(parentElement instanceof EObject) {

			return getChildren((EObject)parentElement).toArray();
		}

		return new Object[0];
	}

	/**
	 * Return child {@link EObject}s of the parent {@link EObject} by using
	 * registered {@link IModelElementHandler}
	 */
	public List<? extends EObject> getChildren(EObject parentElement) {
		IModelElementHandler<EObject> base =
				IModelElementHandlerService.INSTANCE.getModelElementHandler(parentElement);
		if(base != null) {
			return base.getSubnodes(parentElement);
		}

		return Collections.emptyList();
	}
}
