/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2015 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.allocation;

import org.eclipse.draw2d.PolylineConnection;
import org.eclipse.gef.EditPart;
import org.fortiss.tooling.base.model.base.ConnectionSegmentBase;
import org.fortiss.tooling.base.ui.editpart.ConnectionEditPartBase;
import org.fortiss.tooling.base.ui.layout.IDiagramLayoutConfiguration;

/**
 * Base class for allocation connection edit parts. It provides the figure, labels for the
 * connection name and a highlighted simulation value, as well as, bend point
 * handling. The basic extension is refresh visuals as only connections between visible edit parts
 * are shown.
 * 
 * 
 * @author eder
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @param <T>
 * @ConQAT.Rating RED Hash:
 */
public abstract class AllocationConnectionEditPartBase<T extends ConnectionSegmentBase> extends
		ConnectionEditPartBase<T> {

	/** Constructor. */
	protected AllocationConnectionEditPartBase(T modelElement,
			IDiagramLayoutConfiguration layoutConfiguration) {
		super(modelElement, layoutConfiguration);

	}

	/** {@inheritDoc} */
	@Override
	protected void refreshVisuals() {
		super.refreshVisuals();

		EditPart target = getTarget();
		EditPart source = getSource();

		// prevent connections from being shown in the wrong hierarchical layers
		if(target == null || source == null) {
			figure.setVisible(false);
		} else {
			figure.setVisible(true);
		}
	}

	/** {@inheritDoc} */
	@Override
	protected PolylineConnection createFigure() {
		PolylineConnection createFigure = super.createFigure();
		createFigure.setLineWidth(createFigure.getLineWidth() * 2);
		return createFigure;
	}
}
