/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2015 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.command;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.base.dnd.AllocationConnectionDragContext;
import org.fortiss.tooling.base.dnd.ConnectionDragContext;
import org.fortiss.tooling.kernel.service.IConnectionCompositorService;

/**
 * The connection command used for allocation. Basic difference to {@link ConnectCommand} is that
 * the allocation root object is passed.
 * 
 * @author eder
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public class AllocationConnectCommand extends ConnectCommand {

	/** Constructor. */
	public AllocationConnectCommand(ConnectionDragContext context) {
		super(context);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canExecute() {
		if(context instanceof AllocationConnectionDragContext) {
			return IConnectionCompositorService.INSTANCE.canConnect(context.getSource(),
					context.getTarget(),
					((AllocationConnectionDragContext)context).getAllocationRoot(), context);
		}
		return super.canExecute();
	}

	/** {@inheritDoc} */
	@Override
	public void execute() {
		if(context instanceof AllocationConnectionDragContext) {
			EObject commonParent = ((AllocationConnectionDragContext)context).getAllocationRoot();
			IConnectionCompositorService.INSTANCE.connect(context.getSource(), context.getTarget(),
					commonParent, context);
		} else {
			super.execute();
		}
	}

}
