/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.utils;

import org.eclipse.swt.graphics.Image;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity;
import org.fortiss.tooling.kernel.ui.service.IMarkerService;

/**
 * Utility class to obtain decoration icons for use with the {@link IMarkerService}.
 * 
 * @author barner
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 60BCFA87AD86A972CD3596BE3167865C
 */
public class DecorationIconUtils {

	/** Cached small error icon. */
	private static Image smallErrorIcon = IMarkerService.INSTANCE
			.getImageFor(ESeverity.ERROR, true).createImage();

	/** Cached large error icon. */
	private static Image largeErrorIcon = IMarkerService.INSTANCE.getImageFor(ESeverity.ERROR,
			false).createImage();

	/** Cached small warning icon. */
	private static Image smallWarningIcon = IMarkerService.INSTANCE.getImageFor(ESeverity.WARNING,
			true).createImage();

	/** Cached large warning icon. */
	private static Image largeWarningIcon = IMarkerService.INSTANCE.getImageFor(ESeverity.WARNING,
			false).createImage();

	/**
	 * <p>
	 * Returns an {@link IMarkerService} decoration icon for the specified {@link ESeverity}.
	 * </p>
	 * <p>
	 * Note: The returned {@link Image} <b>must NOT</b> be disposed</b>.
	 * </p>
	 */
	public static Image getMarkerServiceDecorationIcon(ESeverity severity, boolean useSmallImage) {
		switch(severity) {
			case ERROR:
				return useSmallImage ? smallErrorIcon : largeErrorIcon;

			case WARNING:
				return useSmallImage ? smallWarningIcon : largeWarningIcon;

			default:
		}

		return null;
	}
}
