/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2015 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.model.layout.impl;

import org.fortiss.tooling.base.model.layout.Dimension;
import org.fortiss.tooling.base.utils.LayoutModelElementFactory;

/**
 * Static implementation for the {@link Dimension} layout element.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 67CAA5E7DABFCF4AD244EC5CC2861813
 */
public class DimensionStaticImpl {

	/**
	 * Scales the given {@link Dimension} by the given factor.
	 * 
	 * @param dim
	 *            {@link Dimension} to be scaled.
	 * @param factor
	 *            Scaling factor.
	 * @return The scaled input Dimension.
	 */
	public static Dimension scale(Dimension dim, double factor) {
		Dimension retDimension =
				LayoutModelElementFactory.createDimension(0, 0, dim.toString() + "_scaled");
		retDimension.setHeight((int)Math.floor(dim.getHeight() * factor));
		retDimension.setWidth((int)Math.floor(dim.getWidth() * factor));
		return retDimension;
	}
}
