/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2012 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.internal.LibraryService;
import org.fortiss.tooling.kernel.model.ILibrary;
import org.fortiss.tooling.kernel.model.ILibraryElement;
import org.fortiss.tooling.kernel.model.ILibraryElementReference;
import org.fortiss.tooling.kernel.model.ILibraryPackage;

/**
 * The library service provides high level access to the library.
 * 
 * @author ratiu
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating GREEN Hash: B512269C9F0DFC44C45930CCAC191AEE
 */
public interface ILibraryService {

	/** Returns the singleton instance of the service. */
	public static final ILibraryService INSTANCE = new LibraryService();

	/**
	 * Returns true if the parameter is a shadow of a library element.
	 * A shadow is a temporary copy of an element, contained inside an
	 * {@link ILibraryElementReference}.
	 */
	public boolean isLibraryElementShadow(EObject anObject);

	/**
	 * Returns true if the library reference is dirty. A library reference is dirty when the
	 * shadowed library element from inside is inconsistent with the library.
	 */
	public boolean isDirty(ILibraryElementReference libRef);

	/** Sets the dirty flag for a library reference. */
	public void setDirty(ILibraryElementReference libRef, boolean flag);

	/** Finds a {@link ILibraryElement} in the library. */
	public ILibraryElement findLibraryElementByURI(String uri);

	/** Returns the list of {@link ILibraryElement} from all libraries loaded in the workspace. */
	public List<ILibraryElement> getLibraryElementsFromAllWorkspaceLibraries();

	/** Returns the list of {@link ILibrary} objects loaded in the workspace. */
	public List<ILibrary> getLibrariesFromWorkspace();

	/** Returns all {@link ILibraryPackage} objects from library. */
	public List<ILibraryPackage> getAllLibraryPackages(ILibrary lib);

	/** Ensures that the wrapped model element behind this reference is up to date. */
	public void ensureWrappedElementIsUpToDate(final ILibraryElementReference ref);

	/** Ensures that all children objects that reference library elements are up to date. */
	public void ensureChildrenLibraryReferenceAreUpToDate(final EObject context);

	/** Adds an element to the library in a given library package. */
	public void addElementToLibrary(final ILibraryPackage pack, final EObject obj);
}
