/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.jface;

import java.util.Map;
import java.util.Map.Entry;

import org.eclipse.jface.viewers.ColumnLabelProvider;

/**
 * Label provider for maps. This is usally used in conjunction with
 * {@link MapContentProvider}.
 * 
 * @author deissenb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 28729D14890FED440A142D2FBD7AA585
 */
public class MapColumnLabelProvider extends ColumnLabelProvider {
	/**
	 * Flag that signals if the key or the value should be returned. If this is
	 * true, the key is returned.
	 */
	private final boolean key;

	/**
	 * Create new column provider.
	 * 
	 * @param key
	 *            Flag that signals if the key or the value should be returned.
	 *            If this is true, the key is returned.
	 */
	public MapColumnLabelProvider(boolean key) {
		this.key = key;
	}

	/**
	 * If element is not an instance of {@link java.util.Map.Entry}, this
	 * returns <code>null</code>. Otherwise, the <code>toString()</code> of the
	 * key or value is returned.
	 */
	@Override
	public String getText(Object element) {
		if (!(element instanceof Map.Entry<?,?>)) {
			return null;
		}
		Map.Entry<?, ?> entry = (Entry<?, ?>) element;
		if (key) {
			return entry.getKey().toString();
		}
		return entry.getValue().toString();
	}
}